pub fn apply_decoded_traits(
tree: TraitTreeFlat,
decoded: &DecodedTraitLoadout,
) -> TraitTreeWithSelectionsExpand description
Applies decoded positional selections to a trait tree using all_node_ids as the wire order.
pub fn apply_decoded_traits(
tree: TraitTreeFlat,
decoded: &DecodedTraitLoadout,
) -> TraitTreeWithSelectionsApplies decoded positional selections to a trait tree using all_node_ids as the wire order.